version 10
set more off
clear

*******************************************************************************
* Rauh & Schneider / JCMS / 2013: There is no such thing as a free open sky...
* Estimation of market models 
*******************************************************************************


use FCTBwind.dta, clear

*--------------------------------------------------------------------------------------
* Aim of the following procedure is to find the best fitting normal return OLS estimations 
* (i.e. market models) for each airline return series across the whole sample.
* 
* For each dependent variable [dv] there are varying independent variables
* (a) a blue chip index [bc] of the exchange where the airline is primarily listed
* (b) a broad based index [bb] of the exchange where the airline is primarily listed
* (c) a return series of jet grade kerosene spot prices [oil] 
*
* In addition to this complexity, different lag structures [l.] are to be evaluated
* and each model should be estimated with and without a constant.
* 
* This results in a rather large set of possible model setup combinations. To deal 
* with this, the temporary programm 'mm' is established that estimates each possible
* model setup relying on the respective independent variables.
*
* For each unique model, the values of R-squared, adjusted R-squared, as well as of
* the Akaike and Schwarz information criteria are stored in a separate dataset.
*
* Based on these data, the best fitting market model for each airline return series
* can be obtained.
*-------------------------------------------------------------------------------------


capture program drop mm

quietly program mm															/* Establishes the program "mm" in the temporary memory */
	version 9.2
	args dv bc bb oil															/* Defines the arguments (syntax), the user has to provide with the mm command (see notes above) */
	tempname memhold
	quietly postfile `memhold' str10 dv str50 model variant r2 r2a aic bic obs using `dv'_mm.dta, replace	/* Establishing another dataset to hold the evaluation criteria for each market-model */
	
	quietly reg `dv' `bc', robust													/* Calculating the respective market model. Here: Variant 1: dv = bc */
	local model "reg `dv' `bc', robust"												/* Storing the regression command in a string */
	local variant = 1															/* Variant of the model setup (see text for details) */
	local r2 = e(r2)															/* Storing r squared */
	local r2a = e(r2_a)														/* Storing adjusted r squared */
	local aic = -2*e(ll)+2*(e(df_m)+1)												/* Calculating and storing the Akaike IC */
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)											/* Calculating and storing the Baysian IC */
	local obs = e(N)															/* Storing the number of obs used in model estimation */
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')			/* Writing the stored data in the external dataset */
	
	quietly reg `dv' `bc', robust noconstant											/* Above procedure is repeated for each variant of market model setup */												
	local model "reg `dv' `bc', robust noconstant"										/* Here: Variant 2: dv = bc (no constant) */
	local variant = 2
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' `bb', robust													/* Variant 3: dv = bb */
	local model "reg `dv' `bb', robust"
	local variant = 3
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' `bb', robust noconstant											/* Variant 4: dv = bb (no constant) */												
	local model "reg `dv' `bb', robust noconstant"
	local variant = 4
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' l.`bc', robust												/* Variant 5: dv = l.bc */
	local model "reg `dv' l.`bc', robust"
	local variant = 5
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bc', robust noconstant										/* Variant 6: dv = l.bc (no constant) */								
	local model "reg `dv' l.`bc', robust noconstant"
	local variant = 6
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bb', robust												/* Variant 7: dv = l.bb */
	local model "reg `dv' l.`bb', robust"
	local variant = 7
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bb', robust noconstant										/* Variant 8: dv = l.bb (no constant) */								
	local model "reg `dv' l.`bb', robust noconstant"
	local variant = 8
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' `bc' `oil', robust												/* Variant 9: dv = bc + oil */
	local model "reg `dv' `bc' `oil', robust"
	local variant = 9
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' `bc' `oil', robust noconstant										/* Variant 10: dv = bc + oil (no constant) */	
	local model "reg `dv' `bc' `oil', robust noconstant"
	local variant = 10
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' `bb' `oil', robust												/* Variant 11: dv = bb + oil */
	local model "reg `dv' `bb' `oil', robust"
	local variant = 11
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' `bb' `oil', robust noconstant										/* Variant 12: dv = bb + oil (no constant) */		
	local model "reg `dv' `bb' `oil', robust noconstant"
	local variant = 12
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')		

	quietly reg `dv' l.`bc' `oil', robust											/* Variant 13: dv = l.bc + oil */
	local model "reg `dv' l.`bc' `oil', robust"
	local variant = 13
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' l.`bc' `oil', robust	noconstant									/* Variant 14: dv = l.bc + oil (no constant) */
	local model "reg `dv' l.`bc' `oil', robust noconstant"
	local variant = 14
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')					/* Variant 15: dv = l.bb + oil */

	quietly reg `dv' l.`bb' `oil', robust												
	local model "reg `dv' l.`bb' `oil', robust"
	local variant = 15
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bb' `oil', robust noconstant									/* Variant 16: dv = l.bb + oil (no constant)*/
	local model "reg `dv' l.`bb' `oil', robust noconstant"
	local variant = 16
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' `bc' l.`oil', robust											/* Variant 17: dv = bc + l.oil */
	local model "reg `dv' `bc' l.`oil', robust"
	local variant = 17
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' `bc' l.`oil', robust noconstant									/* Variant 18: dv = bc + l.oil (no constant) */
	local model "reg `dv' `bc' l.`oil', robust noconstant"
	local variant = 18
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' `bb' l.`oil', robust											/* Variant 19: dv = bb + l.oil */
	local model "reg `dv' `bb' l.`oil', robust"
	local variant = 19
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' `bb' l.`oil', robust noconstant									/* Variant 20: dv = bb + l.oil (no constant) */	
	local model "reg `dv' `bb' l.`oil', robust noconstant"
	local variant = 20
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bc' l.`oil', robust											/* Variant 21: dv = l.bc + l.oil */
	local model "reg `dv' l.`bc' l.`oil', robust"
	local variant = 21
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bc' l.`oil', robust noconstant									/* Variant 22: dv = l.bc + l.oil (no constant) */
	local model "reg `dv' l.`bc' l.`oil', robust noconstant"
	local variant = 22
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	quietly reg `dv' l.`bb' l.`oil', robust											/* Variant 23: dv = l.bb + l.oil */
	local model "reg `dv' l.`bb' l.`oil', robust"
	local variant = 23
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m)+1)
	local bic = -2*e(ll)+ln(e(N))*(e(df_m)+1)
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')
	
	quietly reg `dv' l.`bb' l.`oil', robust noconstant									/* Variant 24: dv = l.bb + l.oil (no constant) */
	local model "reg `dv' l.`bb' l.`oil', robust noconstant"
	local variant = 24
	local r2 = e(r2)
	local r2a = e(r2_a)
	local aic = -2*e(ll)+2*(e(df_m))
	local bic = -2*e(ll)+ln(e(N))*(e(df_m))
	local obs = e(N)
	post `memhold' ("`dv'") ("`model'") (`variant') (`r2') (`r2a') (`aic') (`bic') (`obs')

	postclose `memhold'

end



*------------------------------------------------------------
* In the following, the program is executed for each airline
* and the respective indices and oil prices
*
* Syntax: mm dv bc bb oil
*------------------------------------------------------------

sort t
quietly tsset t

* Air France
mm dafr dfchi dsbf250 dfuelro

* Alitalia
mm daza dmib30 dmibtel dfuelro

* Austrian Airlines
mm daua datx dwbi dfuelro

* British Airways
mm dbaw dftse dftas dfuelro

* Finnair
mm dfin dhex25 dhex dfuelro

* Iberia
mm dibe dibex dsmsi dfuelro

* KLM
mm dklm daex daax dfuelro

* Lufthansa
mm ddlh ddaxk dfwbxx dfuelro

* SAS
mm dsas domx dsxaxpi dfuelro

* Swissair
mm dswr dssmi dssmiex dfuelro

* American Airlines
mm daal ddji dnya dfuelny

* Continental Airlines
mm dcoa ddji dnya dfuelny



*------------------------------------------------------------------------------------------
* Combining the airline specific data sets containing the market model evaluation criteria
*------------------------------------------------------------------------------------------

use dafr_mm.dta, clear

local airlines daza daua dbaw dfin dibe dklm ddlh dsas dswr daal dcoa			/* Local that contains all airline return series except for AFR */

foreach var of local airlines {								/* Appending the airline specific datasets */
	append using `var'_mm.dta
 }


* The resulting data set contains the information criteria for each airline and each model variant

label data " Rauh & Schneider / JCMS / 2013): OLS Market model evaluation"

label var dv "Dependent variable"
label var model "Executed regression command"
label var variant "Market model setup variant"
label var r2 "R-squared of model"
label var r2a "Adjusted R-squared of model"
label var aic "Akaike IC of model"
label var bic "Schwarz / Bayesian IC of model"
label var obs "Number of obs used in estimation"

quietly compress
quietly save marketmodels.dta, replace


local airlines dafr `airlines' 								/* Adding AFR to the local macro */

foreach var of local airlines {								/* Deleting the airline specific datasets */
	erase `var'_mm.dta
}


*---------------------------------------------------------
* Choosing the 'best' model for each airline return series
*---------------------------------------------------------


* According to adjusted R-squared, the following OLS models are advisable
*************************************************************************

foreach var of local airlines {								/* Looping over all airline return series */
	quietly sum r2a if dv == "`var'"						/* Summarizing R-squared for the respective airline return series */
	quietly levelsof model if r2a==r(max), local(`var'bestmodelr2)			/* Storing the regression command that maximised r-squared - useful for later AR calculation */
	quietly sum r2a if dv == "`var'"
	quietly levelsof variant if r2a==r(max), local(bvariant)			/* Storing the variant number that maximised r-squared */
	di "`var': 	Variant `bvariant'"						/* Display return series name and variant number that maximised r-squared */
	di "		"``var'bestmodelr2'""						/* Display regression command that maximised r-squared */
 }




*-----------------------------------------
* Generating dummies for individual events
*-----------------------------------------

use FCTBwind.dta, clear

quietly tab ev_id, gen(event)

forvalues i = 1(1)27 {
	quietly replace event`i'=0 if event`i'==.
}




*--------
* Saving
*--------

order t date  

quietly compress
save FCTB.dta, replace


exit

